pub struct Ident {
pub value: String,
pub quote_style: Option<char>,
}Expand description
An identifier, decomposed into its value or character data and the quote style.
Fields
value: StringThe value of the identifier without quotes.
quote_style: Option<char>The starting quote if any. Valid quote characters are the single quote, double quote, backtick, and opening square bracket.
Implementations